@@ -8,6 +8,8 @@ OC.L10N.register(
     "Upcoming events" : "Próximos eventos",
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
+    "Anniversary" : "Aniversario",
+    "Personal" : "Personal",
     "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
     "Previous day" : "Día previo",
     "Previous week" : "Semana previa",
@@ -15,7 +17,6 @@ OC.L10N.register(
     "Next day" : "Proximo día",
     "Next week" : "Proxima semana",
     "Next month" : "Proximo mes",
-    "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -33,12 +34,14 @@ OC.L10N.register(
     "Deleted" : "Eliminado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Copy internal link" : "Copiar enlace interno",
     "Share link" : "Compartir link",
     "Copy public link" : "Copiar link publico",
     "Copied code" : "Código copiado",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "No users or groups" : "No hay usuarios ni grupos.",
+    "Save" : "Guardar",
     "Filename" : "Nombre de archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
@@ -56,7 +59,6 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Save" : "Guardar",
     "Update" : "Actualizar",
     "Your email address" : "Su dirección de correo electrónico",
     "Notification" : "Notificación",
@@ -76,17 +78,14 @@ OC.L10N.register(
     "available" : "disponible",
     "More" : "Más",
     "Global" : "Global",
-    "Personal" : "Personal",
+    "Subscribe" : "Suscribirse",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
-    "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "Prev" : "Prev",
-    "Next" : "Siguiente",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
