@@ -9,7 +9,8 @@ OC.L10N.register(
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
     "Where:" : "Dónde:",
-    "New event" : "Nuevo evento",
+    "Anniversary" : "Aniversario",
+    "Personal" : "Personal",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -28,6 +29,7 @@ OC.L10N.register(
     "Share link" : "Compartir liga",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
@@ -47,7 +49,6 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Save" : "Guardar",
     "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
@@ -67,17 +68,14 @@ OC.L10N.register(
     "available" : "disponible",
     "More" : "Más",
     "Global" : "Global",
-    "Personal" : "Personal",
+    "Subscribe" : "Suscribir",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
-    "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "Prev" : "Prev",
-    "Next" : "Siguiente",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
