@@ -22,18 +22,22 @@ OC.L10N.register(
     "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
     "Date:" : "Data:",
     "Where:" : "Unde:",
+    "Anniversary" : "Aniversare",
+    "Personal" : "Personal",
+    "Vacation" : "Vacanță",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
     "Previous week" : "Săptămâna anterioară",
     "Previous month" : "Luna anterioară",
     "Next day" : "Ziua următoare",
     "Next week" : "Saptămâna următoare",
+    "Next year" : "Aanul viitor",
     "Next month" : "Luna următoare",
-    "New event" : "Eveniment nou",
     "Today" : "Astăzi",
     "Day" : "Zi",
     "Week" : "Săptămâna",
     "Month" : "Luna",
+    "Year" : "An",
     "List" : "Listă",
     "Preview" : "Previzualizare",
     "Copy link" : "Copiază link",
@@ -275,12 +279,9 @@ OC.L10N.register(
     "Subscribe" : "Abonare",
     "Time:" : "Timp:",
     "Booked for:" : "Rezervat pentru:",
-    "Personal" : "Personal",
     "Details" : "Detalii",
     "Attendees" : "Participanți",
     "Close" : "Închide",
-    "Anniversary" : "Aniversare",
-    "Vacation" : "Vacanță",
     "Midnight on the day the event starts" : "La miezul nopții în ziua în care evenimentul începe",
     "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : [" %n zi înainte de evenimentul de la {formattedHourMinute}","%n zile înainte de evenimentul de la {formattedHourMinute}","%n de zile înainte de evenimentul de la {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n săptămână înainte de evenimentul de la {formattedHourMinute}","%n săptămânii înainte de evenimentul de la {formattedHourMinute}","%n de săptămânii înainte de evenimentul de la {formattedHourMinute}"],
