@@ -164,7 +164,8 @@ class AppointmentConfigController extends Controller {
 		?array $calendarFreeBusyUris = null,
 		?int $start = null,
 		?int $end = null,
-		?int $futureLimit = null): JsonResponse {
+		?int $futureLimit = null,
+		?bool $createTalkRoom = false): JsonResponse {
 		if ($this->userId === null) {
 			return JsonResponse::fail();
 		}
@@ -192,7 +193,8 @@ class AppointmentConfigController extends Controller {
 				$calendarFreeBusyUris,
 				$start,
 				$end,
-				$futureLimit
+				$futureLimit,
+				$createTalkRoom
 			);
 			return JsonResponse::success($appointmentConfig);
 		} catch (ServiceException $e) {
@@ -240,7 +242,8 @@ class AppointmentConfigController extends Controller {
 		?array $calendarFreeBusyUris = null,
 		?int $start = null,
 		?int $end = null,
-		?int $futureLimit = null): JsonResponse {
+		?int $futureLimit = null,
+		?bool $createTalkRoom = false): JsonResponse {
 		if ($this->userId === null) {
 			return JsonResponse::fail(null, Http::STATUS_NOT_FOUND);
 		}
@@ -274,6 +277,7 @@ class AppointmentConfigController extends Controller {
 		$appointmentConfig->setStart($start);
 		$appointmentConfig->setEnd($end);
 		$appointmentConfig->setFutureLimit($futureLimit);
+		$appointmentConfig->setCreateTalkRoom($createTalkRoom === true);
 
 		try {
 			$appointmentConfig = $this->appointmentConfigService->update($appointmentConfig);
