@@ -27,14 +27,13 @@ declare(strict_types=1);
 namespace OCA\Calendar\Service\Appointments;
 
 use Exception;
-use OC\Notification\Notification;
-use OC\URLGenerator;
 use OCA\Calendar\Db\AppointmentConfig;
 use OCA\Calendar\Db\Booking;
 use OCA\Calendar\Exception\ServiceException;
 use OCP\Defaults;
 use OCP\IDateTimeFormatter;
 use OCP\IL10N;
+use OCP\IURLGenerator;
 use OCP\IUser;
 use OCP\IUserManager;
 use OCP\L10N\IFactory;
@@ -42,6 +41,7 @@ use OCP\Mail\IEMailTemplate;
 use OCP\Mail\IMailer;
 use OCP\Notification\IManager;
 use Psr\Log\LoggerInterface;
+use function htmlspecialchars;
 use function implode;
 
 class MailService {
@@ -55,7 +55,7 @@ class MailService {
 	private $defaults;
 	/** @var LoggerInterface */
 	private $logger;
-	/** @var URLGenerator */
+	/** @var IURLGenerator */
 	private $urlGenerator;
 	/** @var IDateTimeFormatter */
 	private $dateFormatter;
@@ -69,7 +69,7 @@ class MailService {
 		IL10N $l10n,
 		Defaults $defaults,
 		LoggerInterface $logger,
-		URLGenerator $urlGenerator,
+		IURLGenerator $urlGenerator,
 		IDateTimeFormatter $dateFormatter,
 		IFactory $lFactory,
 		IManager $notificationManager) {
@@ -97,9 +97,11 @@ class MailService {
 		}
 
 		$fromEmail = $user->getEMailAddress();
+		if ($fromEmail === null) {
+			throw new ServiceException('Organizer has no email set');
+		}
 		$fromName = $user->getDisplayName();
 
-
 		$sys = $this->getSysEmail();
 		$message = $this->mailer->createMessage()
 			->setFrom([$sys => $fromName])
@@ -117,17 +119,17 @@ class MailService {
 		// Heading
 		$summary = $this->l10n->t("Dear %s, please confirm your booking", [$booking->getDisplayName()]);
 		$template->addHeading($summary);
-		
+
 		$bookingUrl = $this->urlGenerator->linkToRouteAbsolute('calendar.booking.confirmBooking', ['token' => $booking->getToken()]);
 		$template->addBodyButton($this->l10n->t('Confirm'), $bookingUrl);
-		
+
 		$template->addBodyListItem($user->getDisplayName(), 'Appointment with:');
 		if (!empty($config->getDescription())) {
 			$template->addBodyListItem($config->getDescription(), 'Description:');
 		}
 
 		// Create Booking overview
-		$this->addBulletList($template, $this->l10n, $booking, $config->getLocation());
+		$this->addBulletList($template, $this->l10n, $booking, $config);
 
 		$bodyText = $this->l10n->t('This confirmation link expires in %s hours.', [(BookingService::EXPIRY / 3600)]);
 		$template->addBodyText($bodyText);
@@ -168,6 +170,9 @@ class MailService {
 		}
 
 		$fromEmail = $user->getEMailAddress();
+		if ($fromEmail === null) {
+			throw new ServiceException('Organizer has no email set');
+		}
 		$fromName = $user->getDisplayName();
 
 		$sys = $this->getSysEmail();
@@ -194,7 +199,7 @@ class MailService {
 		}
 
 		// Create Booking overview
-		$this->addBulletList($template, $this->l10n, $booking, $config->getLocation());
+		$this->addBulletList($template, $this->l10n, $booking, $config);
 
 		$bodyText = $this->l10n->t('If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page.');
 		$template->addBodyText($bodyText);
@@ -224,7 +229,7 @@ class MailService {
 	private function addBulletList(IEMailTemplate $template,
 		IL10N $l10n,
 		Booking $booking,
-		?string $location = null):void {
+		AppointmentConfig $config):void {
 		$template->addBodyListItem($booking->getDisplayName(), $l10n->t('Appointment for:'));
 
 		$l = $this->lFactory->findGenericLanguage();
@@ -238,8 +243,19 @@ class MailService {
 
 		$template->addBodyListItem($relativeDateTime, $l10n->t('Date:'));
 
-		if (!empty($location)) {
-			$template->addBodyListItem($location, $l10n->t('Where:'));
+		if (!$booking->isConfirmed() && $config->getCreateTalkRoom()) {
+			$template->addBodyListItem($l10n->t('You will receive a link with the confirmation email'), $l10n->t('Where:'));
+		} elseif (!$booking->isConfirmed() && !empty($config->getLocation())) {
+			$template->addBodyListItem($config->getLocation(), $l10n->t('Where:'));
+		} elseif ($booking->isConfirmed() && $booking->getTalkUrl() !== null) {
+			$template->addBodyListItem(
+				'<a href="' . htmlspecialchars($booking->getTalkUrl()) . '">' . $booking->getTalkUrl() . '</a>',
+				$l10n->t('Where:'),
+				'',
+				$booking->getTalkUrl(),
+			);
+		} elseif ($booking->isConfirmed() && !empty($config->getLocation())) {
+			$template->addBodyListItem($config->getLocation(), $l10n->t('Where:'));
 		}
 
 		if (!empty($booking->getDescription())) {
@@ -263,12 +279,16 @@ class MailService {
 			throw new ServiceException('Could not find organizer');
 		}
 
+		$toEmail = $user->getEMailAddress();
+		if ($toEmail === null) {
+			throw new ServiceException('Organizer has no email set');
+		}
 		$fromName = $user->getDisplayName();
 
 		$sys = $this->getSysEmail();
 		$message = $this->mailer->createMessage()
 			->setFrom([$sys => $fromName])
-			->setTo([$user->getEMailAddress() => $booking->getDisplayName()]);
+			->setTo([$toEmail => $booking->getDisplayName()]);
 
 
 		$template = $this->mailer->createEMailTemplate('calendar.confirmOrganizer');
@@ -288,7 +308,7 @@ class MailService {
 		}
 
 		// Create Booking overview
-		$this->addBulletList($template, $this->l10n, $booking, $config->getLocation());
+		$this->addBulletList($template, $this->l10n, $booking, $config);
 		$template->addFooter();
 
 		$attachment = $this->mailer->createAttachment($calendar, 'appointment.ics', 'text/calendar');
@@ -320,7 +340,6 @@ class MailService {
 			$this->lFactory->get('calendar')
 		);
 
-		/** @var Notification $notification */
 		$notification = $this->notificationManager->createNotification();
 		$notification
 			->setApp('calendar')
